@@ -1,17 +1,16 @@
-from __future__ import print_function, division, absolute_import
-
 import ast
+import builtins
+from collections.abc import Mapping
 import os
 import sys
 import threading
+import warnings
 
 try:
     import yaml
 except ImportError:
     yaml = None
 
-from .compatibility import makedirs, builtins, Mapping
-
 
 no_default = "__no_default__"
 
@@ -233,7 +232,7 @@ def ensure_file(source, destination=None, comment=True):
 
     try:
         if not os.path.exists(destination):
-            makedirs(directory, exist_ok=True)
+            os.makedirs(directory, exist_ok=True)
 
             # Atomically create destination.  Parallel testing discovered
             # a race condition where a process can be busy creating the
@@ -302,10 +301,13 @@ class set(object):
 
             if arg is not None:
                 for key, value in arg.items():
+                    key = check_deprecations(key)
                     self._assign(key.split("."), value, config)
             if kwargs:
                 for key, value in kwargs.items():
-                    self._assign(key.split("__"), value, config)
+                    key = key.replace("__", ".")
+                    key = check_deprecations(key)
+                    self._assign(key.split("."), value, config)
 
     def __enter__(self):
         return self.config
@@ -343,6 +345,7 @@ class set(object):
             Whether this operation needs to be recorded to allow for rollback.
         """
         key = canonical_name(keys[0], d)
+
         path = path + (key,)
 
         if len(keys) == 1:
@@ -524,6 +527,60 @@ def expand_environment_variables(config):
         return config
 
 
+deprecations = {
+    "fuse_ave_width": "optimization.fuse.ave-width",
+    "fuse_max_height": "optimization.fuse.max-height",
+    "fuse_max_width": "optimization.fuse.max-width",
+    "fuse_subgraphs": "optimization.fuse.subgraphs",
+    "fuse_rename_keys": "optimization.fuse.rename-keys",
+    "fuse_max_depth_new_edges": "optimization.fuse.max-depth-new-edges",
+}
+
+
+def check_deprecations(key: str, deprecations: dict = deprecations):
+    """ Check if the provided value has been renamed or removed
+
+    Parameters
+    ----------
+    key : str
+        The configuration key to check
+    deprecations : Dict[str, str]
+        The mapping of aliases
+
+    Examples
+    --------
+    >>> deprecations = {"old_key": "new_key", "invalid": None}
+    >>> check_deprecations("old_key", deprecations=deprecations)  # doctest: +SKIP
+    UserWarning: Configuration key "old_key" has been deprecated. Please use "new_key" instead.
+
+    >>> check_deprecations("invalid", deprecations=deprecations)
+    Traceback (most recent call last):
+        ...
+    ValueError: Configuration value "invalid" has been removed
+
+    >>> check_deprecations("another_key", deprecations=deprecations)
+    'another_key'
+
+    Returns
+    -------
+    new: str
+        The proper key, whether the original (if no deprecation) or the aliased
+        value
+    """
+    if key in deprecations:
+        new = deprecations[key]
+        if new:
+            warnings.warn(
+                'Configuration key "{}" has been deprecated. '
+                'Please use "{}" instead'.format(key, new)
+            )
+            return new
+        else:
+            raise ValueError('Configuration value "{}" has been removed'.format(key))
+    else:
+        return key
+
+
 refresh()
 
 
